@@ -9,7 +9,7 @@ require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
 our @EXPORT_OK = qw(minify);
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 bootstrap JavaScript::Minifier::XS $VERSION;
 
@@ -114,8 +114,8 @@ Graham TerMarsch (cpan@howlingfrog.com)
 
 =head1 REPORTING BUGS
 
-Please report bugs via
-L<rt.cpan.org|http://rt.cpan.org/Dist/Display.html?Queue=JavaScript::Minifier::XS>,
+Please report bugs via RT
+(L<http://rt.cpan.org/Dist/Display.html?Queue=JavaScript::Minifier::XS>),
 and be sure to include the JavaScript that you're having troubles minifying.
 
 =head1 COPYRIGHT
